@@ -25,6 +25,7 @@
 
 static int64_t video_pts = 0;
 static int64_t audio_pts = 0;
+static int64_t first_pts = 0;
 
 AVFormatContext *mp4_create_context(const char *filename)
 {
@@ -96,10 +97,10 @@ int mp4_write_packet(
         int stream_index,
         uint8_t *outbuf,
         uint32_t outbuf_size,
+        uint64_t pts,
         int flags)
 {
     AVPacket *outpacket = codec_data->outpkt;
-    //= codec_data->outpkt;
     outpacket->data = (uint8_t*)calloc((unsigned int)outbuf_size, sizeof(uint8_t));
 
     memcpy(outpacket->data, outbuf, outbuf_size);
@@ -117,7 +118,12 @@ int mp4_write_packet(
         getLoadLibsInstance()->m_av_packet_rescale_ts(outpacket, time_base, video_time);
         getAvformat()->m_av_write_frame(mp4_ctx, outpacket);
 
-        video_pts++;
+        set_video_time_capture((double)(pts)/1000/1000000);
+        if (first_pts == 0) {
+            first_pts = pts;
+        } else {
+            video_pts = (double)(pts - first_pts) / 1000000 / 33;
+        }
     }
 
     if(codec_data->codec_context->codec_type == AVMEDIA_TYPE_AUDIO) {
@@ -149,6 +155,7 @@ void mp4_destroy_context(AVFormatContext *mp4_ctx)
 {
     video_pts = 0;
     audio_pts = 0;
+    first_pts = 0;
     if(mp4_ctx != NULL)
     {
         getAvformat()->m_avformat_free_context(mp4_ctx);
