@@ -82,7 +82,8 @@ videowidget::videowidget(DWidget *parent)
       m_GridType(Grid_None),
       m_videoWriter(nullptr),
       m_filterType(filter_Normal),
-      m_exposure(0)
+      m_exposure(0),
+      m_videoFormat("mp4")
 {
 #ifndef __mips__
     if (!get_wayland_status()) {
@@ -226,6 +227,10 @@ videowidget::videowidget(DWidget *parent)
 
     // 默认不显示网格线
     setGridType(Grid_None);
+
+    if (dc::Settings::get().getOption("outsetting.outformat.vidformat").toInt() ||
+            DataManager::instance()->encodeEnv() != FFmpeg_Env)
+        m_videoFormat = "webm";
 }
 
 //延迟加载
@@ -239,10 +244,8 @@ void videowidget::delayInit()
     setFlash(dc::Settings::get().getOption("photosetting.Flashlight.Flashlight").toBool());
     setCapStatus(false);
     m_imgPrcThread->m_bTake = false;
-#ifdef __mips__
     connect(m_imgPrcThread, SIGNAL(SendMajorImageProcessing(QImage *, int)),
             this, SLOT(ReceiveMajorImage(QImage *, int)));
-#else
     if (get_wayland_status() == true) {
         connect(m_imgPrcThread, SIGNAL(SendMajorImageProcessing(QImage *, int)),
                 this, SLOT(ReceiveMajorImage(QImage *, int)));
@@ -254,7 +257,6 @@ void videowidget::delayInit()
                 m_openglwidget, SLOT(slotShowYuv(uchar *, uint, uint)));
     }
 
-#endif
     connect(m_imgPrcThread, SIGNAL(reachMaxDelayedFrames()),
             this, SLOT(onReachMaxDelayedFrames()));
     connect(m_imgPrcThread, SIGNAL(SendFilterImageProcessing(QImage *)),
@@ -743,10 +745,6 @@ void videowidget::showCountdown()
             m_pCamErrItem->hide();
             m_pSvgItem->hide();
             m_pNormalView->hide();
-
-//            QTimer::singleShot(100, this, [=] {
-//                m_openglwidget->show();
-//            });
         }
 
     } else {
@@ -886,6 +884,11 @@ void videowidget::slotGridTypeChanged(int type)
     setGridType(static_cast<GridType>(type));
 }
 
+void videowidget::slotVideoFormatChanged(const QString &format)
+{
+    m_videoFormat = format;
+}
+
 void videowidget::onRecordFrame(uchar *rgb, uint size)
 {
     if (m_videoWriter)
@@ -1080,7 +1083,7 @@ int videowidget::switchCamera(const char *device, const char *devName)
             showCamUsed();
 
         DataManager::instance()->setdevStatus(CAM_CANNOT_USE);
-    } else if (ret == E_NO_DEVICE_ERR) {
+    } else {
         v4l2_dev_t *vd =  get_v4l2_device_handler();
 
         if (vd != nullptr)
@@ -1249,7 +1252,8 @@ void videowidget::startTakeVideo()
     } else {
         if (DataManager::instance()->getdevStatus() == CAM_CANUSE) {
             qDebug() << "start takeVideo";
-            DataManager::instance()->getstrFileName() = "UOS_" + QDateTime::currentDateTime().toString("yyyyMMddHHmmss") + "_" + QString::number(m_nFileID) + ".webm";
+            DataManager::instance()->getstrFileName() = "UOS_" + QDateTime::currentDateTime().toString("yyyyMMddHHmmss") + "_"
+                    + QString::number(m_nFileID) + "." + m_videoFormat;
             emit filename(DataManager::instance()->getstrFileName());
             m_nFileID ++;
 
